@@ -15,7 +15,7 @@ Copyright (C) 1999 Lars Brinkhoff.  See COPYING for terms and conditions.
 #include <unistd_.h>
 #include <string.h>
 #include <syslog_.h>
-#include <getopt_.h>
+#include <getopt.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -38,10 +38,6 @@ Copyright (C) 1999 Lars Brinkhoff.  See COPYING for terms and conditions.
 #define LOG_ERROR LOG_ERR
 #endif
 
-#ifndef HAVE_GETOPT
-#error "This system doesn't provide getopt()."
-#endif
-
 extern int debug_level;
 extern FILE *debug_file;
 
