@@ -145,9 +145,9 @@ parse_arguments (int argc, char **argv, Arguments *arg)
 	{ "content-length", required_argument, 0, 'c' },
 	{ "strict-content-length", no_argument, 0, 'S' },
 	{ "proxy-buffer-size", required_argument, 0, 'B' },
-	{ "proxy-autorization", required_argument, 0, 'A' },
+	{ "proxy-authorization", required_argument, 0, 'A' },
 	{ "max-connection-age", required_argument, 0, 'M' },
-	{ "proxy-autorization-file", required_argument, 0, 'z' },
+	{ "proxy-authorization-file", required_argument, 0, 'z' },
 	{ 0, 0, 0, 0 }
       };
 
@@ -279,6 +279,15 @@ parse_arguments (int argc, char **argv, Arguments *arg)
 		exit (1);
 	      }
 
+	    /*
+	     * If file ends with a "\r\n" or "\n", chop them off.
+	     */
+	    if (s.st_size >= 1 && auth[s.st_size - 1] == '\n')
+	      {
+		s.st_size -=
+		  (s.st_size >= 2 && auth[s.st_size - 2] == '\r') ? 2 : 1;
+	      }
+
 	    auth[s.st_size] = 0;
 	    arg->proxy_authorization = auth;
 	  }
@@ -356,7 +365,7 @@ parse_arguments (int argc, char **argv, Arguments *arg)
 
       if (arg->proxy_authorization != NULL)
 	{
-	  fprintf (stderr, "%s: warning: --proxy-autorization can't be "
+	  fprintf (stderr, "%s: warning: --proxy-authorization can't be "
 		   "used without --proxy\n", arg->me);
 	  arg->proxy_authorization = NULL;
 	}
