@@ -1,7 +1,7 @@
 /*
 tunnel.c
 
-Copyright (C) 1999 Lars Brinkhoff.  See COPYING for terms and conditions.
+Copyright (C) 1999, 2000 Lars Brinkhoff.  See COPYING for terms and conditions.
 
 See tunnel.h for some documentation about the programming interface.
 */
@@ -14,6 +14,7 @@ See tunnel.h for some documentation about the programming interface.
 #include <sys/poll_.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <netinet/tcp.h>
 
 #include "http.h"
 #include "tunnel.h"
@@ -1105,6 +1106,7 @@ tunnel_accept (Tunnel *tunnel)
       else if (n == 0)
 	{
 	  log_error ("tunnel_accept: poll timed out");
+	  errno = ETIMEDOUT;
 	  break;
 	}
 
